@@ -21,7 +21,7 @@ BOOL gCmdLineHitAnyKey = TRUE;
 BOOL gCmdLineContinue = FALSE;
 
 string_obj* gCmdLine;
-int gCmdLineCursor = 0;   // gCmdLinẽoCgPʂł̈ʒuB̕Pʂł[̃J[\PʂłȂ
+int gCmdLineCursor = 0;   // gCmdLineのバイト単位での位置。文字列の文字数単位でも端末上のカーソル単位でもない
 
 string_obj* gCmdLineSaved;
 
@@ -34,7 +34,7 @@ int gHistoryCursor = -1;
 
 void cmdline_write_history()
 {
-    /// qXg[̃TCY ///
+    /// ヒストリーのサイズ ///
     char* size = getenv("HISTORY_SIZE");
     int histsize;
     if(size) {
@@ -85,14 +85,14 @@ puts("\nwriting history....");
 
 void cmdline_read_history()
 {
-    /// qXg ///
+    /// ヒストリを初期化 ///
     int i;
     for(i=0; i<vector_size(gHistory); i++) {
         string_delete(vector_item(gHistory, i));
     }
     vector_clear(gHistory);
 
-    /// qXg.mhisotryǂݍ ///
+    /// ヒストリを.mhisotryから読み込む ///
     char* env = getenv("HISTORY_FILE");
 
     if(env == NULL) {
@@ -146,7 +146,7 @@ void cmdline_final()
 
 void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
 {
-    /// ŏ̋NȂR}hCqXgǂݍ ///
+    /// 最初の起動ならコマンドラインヒストリを読み込み ///
     if(vector_size(gHistory) == 0) cmdline_read_history();
 
     /// 
@@ -155,7 +155,7 @@ void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
     gCmdLineContinue = continue_;
     string_put(gCmdLine, str);
 
-    /// cursor͕Pʂł̈ʒuw肵Ă̂ŃoCgPʂɕϊ
+    /// cursorは文字列単位での位置を指定してくるのでバイト単位に変換する
     if(cursor >= 0 && cursor < str_kanjilen(kUtf8, string_c_str(gCmdLine))) {
         gCmdLineCursor = str_kanjipos2pointer(kUtf8, string_c_str(gCmdLine), cursor) - string_c_str(gCmdLine);
     }
@@ -199,14 +199,14 @@ void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
 }
 
 ///////////////////////////////////////////////////
-// R}hC⊮
+// コマンドライン補完
 ///////////////////////////////////////////////////
 
 ///////////////////////////////////////////////////
-// 
+// 入力
 ///////////////////////////////////////////////////
 
-/// J[\ړ ///
+/// カーソルを移動 ///
 static void cursor_move(int v)
 {
     char* str = string_c_str(gCmdLine);
@@ -284,21 +284,21 @@ void cmdline_input(int meta, int key)
         }
     }
 
-    /// J[\OɈړ ///
+    /// カーソルを前に移動 ///
     else if(key == 6 || key == KEY_RIGHT) {    // CTRL-F
         cursor_move(1);
 
         gHistoryCursor = -1;
     }
 
-    /// J[\Ɉړ ///
+    /// カーソルを後ろに移動 ///
     else if(key == 2 || key == KEY_LEFT) {    // CTRL-B
         cursor_move(-1);
         
         gHistoryCursor = -1;
     }
 
-    /// ɕ񕪈ړ ///
+    /// 後方に文字列分移動 ///
     else if(meta==1 && key == 'b' || meta==1 && key == KEY_LEFT // Meta-b CTRL-LEFT Meta-Left
         || key==KEY_F(13) || key==KEY_F(17))
     {
@@ -318,7 +318,7 @@ void cmdline_input(int meta, int key)
         gHistoryCursor = -1;
     }
 
-    /// Oɕ񕪈ړ ///
+    /// 前方に文字列分移動 ///
     else if(meta==1 && key == 'f' || meta==1 && key == KEY_RIGHT // Meta-f CTRL-RIGHT Meta-Right
         || key==KEY_F(14) || key==KEY_F(18))
     {
@@ -340,31 +340,31 @@ void cmdline_input(int meta, int key)
         gHistoryCursor = -1;
     }
 
-    /// J[\ԑOɈړ ///
+    /// カーソルを一番前に移動 ///
     else if(key == 1 || key == KEY_HOME) {    // CTRL-A
         cursor_move(-999);
         gHistoryCursor = -1;
     }
 
-    /// J[\𖖔Ɉړ ///
+    /// カーソルを末尾に移動 ///
     else if(key == 5 || key == KEY_END) {    // CTRL-E
         cursor_move(999);
         gHistoryCursor = -1;
     }
 
-    /// 폜 ///
+    /// 後方文字を削除 ///
     else if(key == 4 || key == KEY_DC) {    // CTRL-D DELETE
         string_obj* str = gCmdLine;
         char* cstr = string_c_str(str);
 
-        /// ҏWeLXg̃TCY0ȂR}hCI ///
+        /// 編集テキストのサイズが0ならコマンドライン終了 ///
         if(strlen(cstr) == 0) {
             gCmdLineActive = FALSE;
         }
-        /// ҏWeLXg̃TCY0ȏȂ當폜 ///
+        /// 編集テキストのサイズが0以上なら文字を削除 ///
         else {
             if(gCmdLineCursor < strlen(cstr)) {
-                /// 폜 ///
+                /// 文字を削除 ///
                 int utfpos = str_pointer2kanjipos(kUtf8, cstr, cstr + gCmdLineCursor);
                 char* next_point = str_kanjipos2pointer(kUtf8, cstr, utfpos+1);
 
@@ -374,13 +374,13 @@ void cmdline_input(int meta, int key)
         gHistoryCursor = -1;
     }
 
-    /// 폜 ///
+    /// 後方文字を削除 ///
     else if(key == 8 || key == KEY_BACKSPACE) {    // CTRL-H
         if(gCmdLineCursor > 0) {
             string_obj* str = gCmdLine;
             char* cstr = string_c_str(str);
 
-            /// 폜 ///
+            /// 文字を削除 ///
             int utfpos = str_pointer2kanjipos(kUtf8, cstr, cstr + gCmdLineCursor);
             char* before_point = str_kanjipos2pointer(kUtf8, cstr, utfpos-1);
             int new_cursor = before_point-cstr;
@@ -391,24 +391,24 @@ void cmdline_input(int meta, int key)
         gHistoryCursor = -1;
     }
 
-    /// s폜 ///
+    /// 行を削除 ///
     else if(key == 21) {    // CTRL-U
         string_obj* str = gCmdLine;
         char* cstr = string_c_str(str);
 
-        /// s폜 ///
+        /// 行を削除 ///
         string_put(str, "");
 
         gCmdLineCursor = 0;
         gHistoryCursor = -1;
     }
 
-    /// O폜 ///
+    /// 前方文字列を削除 ///
     else if(key == 23) {     // CTRL-W
         string_obj* str = gCmdLine;
         char* cstr = string_c_str(str);
 
-        /// 폜 ///
+        /// 文字列を削除 ///
         if(gCmdLineCursor > 0) {
             int pos = gCmdLineCursor-1;
             if(cstr[pos]==' ' || cstr[pos]=='/' || cstr[pos]=='\'' || cstr[pos]=='"' || cstr[pos]=='.') {
@@ -429,12 +429,12 @@ void cmdline_input(int meta, int key)
         gHistoryCursor = -1;
     }
 
-    /// 폜 ///
+    /// 後方文字列を削除 ///
     else if(meta==1 && key == 'd' || meta==0 && key==KEY_F(21)) {     // Meta-d CTRL + DELETE
         string_obj* str = gCmdLine;
         char* cstr = string_c_str(str);
 
-        /// 폜 ///
+        /// 後方文字列を削除 ///
         if(cstr[gCmdLineCursor] != 0) {
             int pos = gCmdLineCursor;
             pos++;
@@ -451,12 +451,12 @@ void cmdline_input(int meta, int key)
         gHistoryCursor = -1;
     }
 
-    /// J[\疖܂ō폜 ///
+    /// カーソルから末尾まで削除 ///
     else if(key == 11) {    // CTRL-K
         string_obj* str = gCmdLine;
         char* cstr = string_c_str(str);
 
-        /// ܂ō폜 ///
+        /// 末尾まで削除 ///
         string_erase(str, gCmdLineCursor, string_length(str)-gCmdLineCursor);
         gHistoryCursor = -1;
     }
@@ -516,7 +516,7 @@ void cmdline_input(int meta, int key)
         }
     }
     else if(key == 10 || key == 13) {       // CTRL-J CTRL-M
-        ///  ///
+        /// 初期化 ///
         if(gCmdLineHitAnyKey) {
             mclear();
             mmove(0,0);
@@ -525,19 +525,24 @@ void cmdline_input(int meta, int key)
             mreset_tty();
         }
 
-        /// R}hs ///
-        kitutuki_set_signal();
-        int rcode = kitutuki_shell(string_c_str(gCmdLine), "cmdline", STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
+        /// コマンド実行 ///
+        saphire_set_signal();
+        sRFd* pipein = sRFd_new(STDIN_FILENO);
+        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+        int rcode = saphire_shell(string_c_str(gCmdLine), "cmdline", pipeout, pipein, STDERR_FILENO);
+        sWFd_flash(pipeout);
+        sWFd_delete(pipeout);
+        sRFd_delete(pipein);
         add_history(string_c_str(gCmdLine));
         set_signal_mfiler();
 
         if(!gCmdLineHitAnyKey) {
-            if(rcode < 0) { err_msg(gErrMsg); }
+            if(rcode < 0) { merr_msg(string_c_str(gErrMsg)); }
         }
         else {
-            if(rcode < 0) { printf("%s", gErrMsg); }
+            if(rcode < 0) { printf("%s", string_c_str(gErrMsg)); }
 
-            /// fBNgēǂݍ ///
+            /// ディレクトリ再読み込み ///
             if(strcmp(getenv("VIEW_OPTION"), "2pain") == 0) {
                 filer_reread(0);
                 filer_reread(1);
@@ -570,7 +575,7 @@ void cmdline_input(int meta, int key)
         string_obj* str = gCmdLine;
         char* cstr = string_c_str(str);
 
-        /// ǉ ///
+        /// 文字列を追加 ///
         if(meta == 0 && !(key >= 0 && key <= 27)) {
             char tmp[128];
 
@@ -643,19 +648,19 @@ void cmdline_hcandidate_refresh()
 }
 
 ///////////////////////////////////////////////////
-// `
+// 描写
 ///////////////////////////////////////////////////
 static void cmdline_view_utf8_multi_line()
 {
     const int maxx = mgetmaxx();
     const int maxy = mgetmaxy();
 
-    /// vvg` ///
+    /// プロンプトを描写 ///
     mclear();
 
     mmvprintw(0, 0, "$ ");
     
-    /// es` ///
+    /// 各行を描写 ///
     char* cstr = string_c_str(gCmdLine);
 
     int line = 0;
@@ -672,18 +677,18 @@ static void cmdline_view_utf8_multi_line()
         memcpy(buf, line_top, line_end-line_top);
         buf[line_end-line_top] = 0;
 
-        /// J[\`ʈʒuۑ ///
+        /// カーソル描写位置を保存 ///
         if(line_end == cstr+gCmdLineCursor) {
             cursor_y = line;
             cursor_x = str_termlen(kUtf8, buf);
         }
         
-        /// šE܂ł ///
+        /// 行の限界まできたら ///
         else if(line >= maxy) {
             break;
         }
 
-        /// s̏I܂ŒBĂ ///
+        /// 行の終わりまで達していたら ///
         if(line == 0 && (str_termlen(kUtf8, buf)+2 > maxx)
                 || line > 0 && (str_termlen(kUtf8, buf) > maxx))
         {
@@ -704,7 +709,7 @@ static void cmdline_view_utf8_multi_line()
             line++;
         }
 
-        /// ̏I[܂ŒBĂ ///
+        /// 文字列の終端まで達していたら ///
         else if(!*line_end) {
             if(cursor_x == maxx) {
                 cursor_x = 0;
@@ -716,13 +721,13 @@ static void cmdline_view_utf8_multi_line()
             break;
         }
 
-        /// ȊO ///
+        /// それ以外 ///
         else {
             n++;
         }
     }
 
-    /// J[\ړ ///
+    /// カーソル移動 ///
     if(cursor_y == -1 && cursor_x == -1) {
         mmove(maxy-1, maxx-2);
     }
@@ -809,7 +814,7 @@ static void cmdline_view_utf8()
 
     char* cstr = string_c_str(gCmdLine);
 
-    /// ̂ꂪ邩ǂH ///
+    /// 漢字のずれがあるかどうか？ ///
     BOOL kanji_zure = FALSE;
     int i;
     for(i=0; i<str_kanjilen(kUtf8, cstr); i++) {
@@ -824,14 +829,14 @@ static void cmdline_view_utf8()
         }
     }
 
-    /// [łQsȏ̏ꍇ ///
+    /// 端末上で２行以上の場合 ///
     const int len = str_termlen(kUtf8, cstr);
     if(kanji_zure && (len+3 >= maxx*2)
             || !kanji_zure && (len+2 >= maxx*2)) 
     {
         cmdline_view_utf8_multi_line();
     }
-    /// [łQsȉ̏ꍇ ///
+    /// 端末上で２行以下の場合 ///
     else {
         cmdline_view_utf8_2line();
     }
@@ -839,13 +844,13 @@ static void cmdline_view_utf8()
 
 static void cmdline_view_filer()
 {
-    const int maxx = mgetmaxx();        // ʃTCY
+    const int maxx = mgetmaxx();        // 画面サイズ
     const int maxy = mgetmaxy();
     
     char* env = getenv("PROMPT");
     if(env) {
         string_obj* str = STRING_NEW("");
-        kitutuki_shell3(str, env, "prompt");
+        saphire_shell3(str, env, "prompt");
 
         mmvprintw(maxy -2, 0, "%s", string_c_str(str));
 
@@ -854,21 +859,21 @@ static void cmdline_view_filer()
         string_delete(str);
     }
 
-    /// J[\̃t@C̏` ///          
+    /// カーソル下のファイルの情報を描写 ///          
     char buf[1024];
     sFile* file = filer_cursor_file(adir());
 
     char permission[12];
     strcpy(permission, "----------");
 
-    if(S_ISDIR(file->mLStat.st_mode)) permission[0] = 'd';  // t@C̎
+    if(S_ISDIR(file->mLStat.st_mode)) permission[0] = 'd';  // ファイルの種別
     if(S_ISCHR(file->mLStat.st_mode)) permission[0] = 'c';
     if(S_ISBLK(file->mLStat.st_mode)) permission[0] = 'b';
     if(S_ISFIFO(file->mLStat.st_mode)) permission[0] = 'p';
     if(S_ISLNK(file->mLStat.st_mode)) permission[0] = 'l';
     if(S_ISSOCK(file->mLStat.st_mode)) permission[0] = 's';
 
-    mode_t smode = file->mLStat.st_mode;        // p[~bV
+    mode_t smode = file->mLStat.st_mode;        // パーミッション
     if(smode & S_IRUSR) permission[1] = 'r';
     if(smode & S_IWUSR) permission[2] = 'w';
     if(smode & S_IXUSR) permission[3] = 'x';
@@ -889,7 +894,7 @@ static void cmdline_view_filer()
     
     permission[10] = 0;
 
-    time_t t = file->mLStat.st_mtime;                   // 
+    time_t t = file->mLStat.st_mtime;                   // 時間
     struct tm* tm_ = (struct tm*)localtime(&t);
     
     char buf2[1024];
