@@ -3,35 +3,21 @@
 
 #include "config.h"
 
-#if defined(__CYGWIN__) || defined(__CYGWIN7__)
-#define _LARGEFILE_SOURCE       // サイズが大きいファイルを扱うために必要
+#if defined(__CYGWIN__)
+#define _LARGEFILE64_SOURCE       // サイズが大きいファイルを扱うために必要
 
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
 #define stat64 stat
 #define __off64_t size_t
 #define lstat64 lstat
-
+#undef _LARGEFILE64_SOURCE
 #else
-//#define _LARGE_FILE_API
-//#define _LARGEFILE_SOURCE       // サイズが大きいファイルを扱うために必要
-#define _LARGEFILE64_SOURCE
-//#define _FILE_OFFSET_BITS 64
-//#define __USE_LARGEFILE64
-#define __USE_BSD
-#define __USE_XOPEN_EXTENDED
-#define __KERNEL__      //  無いとS_ISSOCKとかlinux/stat.hで定義されない
+#define _LARGEFILE64_SOURCE      // サイズが大きいファイルを扱うために必要
 
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
 #include <linux/stat.h>
 
-
-#undef __KERNEL__
-//#undef _LARGEFILE_SOURCE
 #undef _LARGEFILE64_SOURCE
-//#undef _FILE_OFFSET_BITS 64
-//#undef __USE_LARGEFILE64
-#undef __USE_BSD
-#undef __USE_XOPEN_EXTENDED
 #endif
 
 extern int lstat (__const char *__restrict __file,
@@ -41,19 +27,10 @@ extern int lstat (__const char *__restrict __file,
 extern int lstat64 (__const char *__restrict __file,
       struct stat64 *__restrict __buf)
      __attribute__ ((__nothrow__)) __attribute__ ((__nonnull__ (1, 2)));
-#endif
-
-#if defined(__LINUX__)
 extern int mknod (__const char *__path, __mode_t __mode, __dev_t __dev)
      __THROW __nonnull ((1));
-#endif
-
-#if defined(__LINUX__)
 extern int symlink (__const char *__from, __const char *__to)
      __THROW __nonnull ((1, 2)) __wur;
-#endif
-
-#if defined(__LINUX__)
 extern int lchown (__const char *__file, __uid_t __owner, __gid_t __group)
      __THROW __nonnull ((1)) __wur;
 #endif
@@ -84,15 +61,19 @@ extern ssize_t readlink (__const char *__restrict __path,
 #ifdef __LINUX__
 
 #include <linux/limits.h>
+/*
 #define __USE_POSIX
 #define __USE_XOPEN_EXTENDED
 #define __USE_POSIX199309
 #define __USE_UNIX98
+*/
 #include <signal.h>
+/*
 #undef __USE_POSIX
 #undef __USE_XOPEN_EXTENDED
 #undef __USE_POSIX199309
 #undef __USE_UNIX98
+*/
 #include <sys/wait.h>
 
 #else
@@ -104,15 +85,15 @@ extern ssize_t readlink (__const char *__restrict __path,
 #endif
 
 
-#include <minato_extra.h>             // 自作ライブラリ群
-#include <minato_curses.h>
-#include <minato_vector.h>
-#include <minato_string.h>
-#include <minato_list.h>
-#include <minato_hash.h>
-#include <minato_debug.h>
+#include <saphire_extra.h>             // 自作ライブラリ群
+#include <saphire_curses.h>
+#include <saphire_vector.h>
+#include <saphire_string.h>
+#include <saphire_list.h>
+#include <saphire_hash.h>
+#include <saphire_debug.h>
 
-#include <kitutuki.h>                // 自作シェルスクリプトライブラリ
+#include <saphire.h>                // 自作シェルスクリプトライブラリ
 
 #include "filer.h"
 
@@ -257,7 +238,7 @@ void cmdline_completion_clear();
 // gui.c
 ///////////////////////////////////////////////////
 char* choise(char* msg, char* str[], int len, int cancel);
-void err_msg(char* msg, ...);
+void merr_msg(char* msg, ...);
 void msg_nonstop(char* msg, ...);
 int select_str(char* msg, char* str[], int len, int cancel);
 int select_str2(char* msg, char* str[], int len, int cancel);
