@@ -113,7 +113,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
         int key = mgetch(&meta);
 
         if(key == 3 || key == 7 || key == 27) {    // CTRL-G and CTRL-C
-            err_msg("file_copy: canceled");
+            merr_msg("file_copy: canceled");
             return FALSE;
         }
     }
@@ -127,7 +127,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
 
     if(stat(dpath, &dstat) < 0) {
         if(dpath[dlen -1] == '/') {
-            err_msg("file_copy: destination_err(%s)", dpath);
+            merr_msg("file_copy: destination_err(%s)", dpath);
             return FALSE;
         }
         else {
@@ -161,11 +161,11 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
 
     /// dpath check ///
     if(stat(dpath, &dstat) < 0) {
-        err_msg("file_copy: destination_err(%s)", dpath);
+        merr_msg("file_copy: destination_err(%s)", dpath);
         return FALSE;
     }
     if(!S_ISDIR(dstat.st_mode)) {
-        err_msg("file_copy: destination err(%s)", dpath);
+        merr_msg("file_copy: destination err(%s)", dpath);
         return FALSE;
     }
 
@@ -176,7 +176,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     strcat(spath2, "/");
         
     if(strstr(dpath, spath2) == dpath) {
-        err_msg("file_copy: destination err(%s)", dpath);
+        merr_msg("file_copy: destination err(%s)", dpath);
         return FALSE;
     }
     
@@ -229,7 +229,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
             struct stat dfstat;
             if(access(dfile, F_OK) == 0) {
                 if(lstat(dfile, &dfstat) < 0) {
-                    err_msg("file_copy: lstat() err2(%s)", dfile);
+                    merr_msg("file_copy: lstat() err2(%s)", dfile);
                     return FALSE;
                 }
         
@@ -294,7 +294,7 @@ override_select_str:
                                 exist_rename_file = access(dfile_tmp, F_OK) == 0;
                                 
                                 if(exist_rename_file) {
-                                    err_msg("same name exists");
+                                    merr_msg("same name exists");
                                 }
                             } while(exist_rename_file);
                             
@@ -355,7 +355,7 @@ dir_copy:
                 null_fun();
                 DIR* dir = opendir(spath);
                 if(dir == NULL) {
-                    err_msg("file_copy: opendir err(%s)", spath);
+                    merr_msg("file_copy: opendir err(%s)", spath);
                     return FALSE;
                 }
 
@@ -368,7 +368,7 @@ dir_copy:
                     if(result <0)
                     {
                         closedir(dir);
-                        err_msg("file_copy: mkdir err(%s)", dfile);
+                        merr_msg("file_copy: mkdir err(%s)", dfile);
                         return FALSE;
                     }
                 }
@@ -399,7 +399,7 @@ dir_copy:
                 if(preserve || move) {
                     if(getuid() == 0) {
                         if(chown(dfile, stat_.st_uid, stat_.st_gid) <0) {
-                            err_msg("file_copy: chown() err(%s)", dfile);
+                            merr_msg("file_copy: chown() err(%s)", dfile);
                             return FALSE;
                         }
                     }
@@ -410,7 +410,7 @@ dir_copy:
                     utb.modtime = stat_.st_mtime;
 
                     if(utime(dfile, &utb) < 0) {
-                        err_msg("file_copy: utime() err(%s)", dfile);
+                        merr_msg("file_copy: utime() err(%s)", dfile);
                         return FALSE;
                     }
                 }
@@ -445,12 +445,12 @@ dir_copy:
                 umask(umask_before);
         
                 if(closedir(dir) < 0) {
-                    err_msg("file_copy: closedir() err");
+                    merr_msg("file_copy: closedir() err");
                     return FALSE;
                 }
                 if(move) {
                     if(rmdir(spath) < 0) {
-                        err_msg("file_copy: rmdir() err(%s)", spath);
+                        merr_msg("file_copy: rmdir() err(%s)", spath);
                         return FALSE;
                     }
                 }
@@ -465,7 +465,7 @@ dir_copy:
                     struct stat dfstat;
                     
                     if(lstat(dfile, &dfstat) < 0) {
-                        err_msg("file_copy: lstat() err(%s)", dfile);
+                        merr_msg("file_copy: lstat() err(%s)", dfile);
                         return FALSE;
                     }
         
@@ -523,7 +523,7 @@ override_select_str2:
                             
                             exist_rename_file = access(dfile_tmp, F_OK) == 0;
                             if(exist_rename_file) {
-                                err_msg("same name exists");
+                                merr_msg("same name exists");
                             }
                         } while(exist_rename_file);
                         
@@ -565,7 +565,7 @@ override_select_str2:
                     struct stat dfstat;
 
                     if(lstat(dfile, &dfstat) < 0) {
-                        err_msg("file_copy: lstat() err3(%s)", dfile);
+                        merr_msg("file_copy: lstat() err3(%s)", dfile);
                         return FALSE;
                     }
 
@@ -599,7 +599,7 @@ file_copy:
                 if(S_ISREG(stat_.st_mode)) {
                     int fd = open(spath, O_RDONLY);
                     if(fd < 0) {
-                        err_msg("file_copy: open(read) err(%s)", spath);
+                        merr_msg("file_copy: open(read) err(%s)", spath);
                         return FALSE;
                     }
                     mode_t umask_before = umask(0);
@@ -609,7 +609,7 @@ file_copy:
                         );
                     umask(umask_before);
                     if(fd2 < 0) {
-                        err_msg("file_copy: open(write) err(%s)", dfile);
+                        merr_msg("file_copy: open(write) err(%s)", dfile);
                         close(fd);
                         return FALSE;
                     }
@@ -633,7 +633,7 @@ file_copy:
                             int key = mgetch(&meta);
 
                             if(key == 3 || key == 7 || key == 27) {    // CTRL-G and CTRL-C
-                                err_msg("file_copy: canceled");
+                                merr_msg("file_copy: canceled");
                                 close(fd);
                                 close(fd2);
                                 return FALSE;
@@ -642,7 +642,7 @@ file_copy:
                         
                         int n = read(fd, buf, BUFSIZ);
                         if(n < 0) {
-                            err_msg("file_copy: read err(%s)", spath);
+                            merr_msg("file_copy: read err(%s)", spath);
                             close(fd);
                             close(fd2);
                             return FALSE;
@@ -653,7 +653,7 @@ file_copy:
                         }
         
                         if(write(fd2, buf, n) < 0) {
-                            err_msg("file_copy: write err(%s)", dfile);
+                            merr_msg("file_copy: write err(%s)", dfile);
                             close(fd);
                             close(fd2);
                             return FALSE;
@@ -661,11 +661,11 @@ file_copy:
                     }
                 
                     if(close(fd) < 0) {
-                        err_msg("file_copy: close err(%s)", spath);
+                        merr_msg("file_copy: close err(%s)", spath);
                         return FALSE;
                     }
                     if(close(fd2) < 0) {
-                        err_msg("file_copy: close err fd2(%s)", dfile);
+                        merr_msg("file_copy: close err fd2(%s)", dfile);
                         return FALSE;
                     }
 
@@ -673,7 +673,7 @@ file_copy:
                     if(preserve || move) {
                         if(getuid() == 0) {
                             if(chown(dfile, stat_.st_uid, stat_.st_gid) < 0) {
-                                err_msg("file_copy: chown() err(%s)", dfile);
+                                merr_msg("file_copy: chown() err(%s)", dfile);
                                 return FALSE;
                             }
                         }
@@ -684,7 +684,7 @@ file_copy:
                         utb.modtime = stat_.st_mtime;
 
                         if(utime(dfile, &utb) < 0) {
-                            err_msg("file_copy: utime() err(%s)", dfile);
+                            merr_msg("file_copy: utime() err(%s)", dfile);
                             return FALSE;
                         }
                         
@@ -724,13 +724,13 @@ file_copy:
                     char link[PATH_MAX];
                     int n = readlink(spath, link, PATH_MAX);
                     if(n < 0) {
-                        err_msg("file_copy: readlink err(%s)", spath);
+                        merr_msg("file_copy: readlink err(%s)", spath);
                         return FALSE;
                     }
                     link[n] = 0;
         
                     if(symlink(link, dfile) < 0) {
-                        err_msg("file_copy: symlink err(%s)", dfile);
+                        merr_msg("file_copy: symlink err(%s)", dfile);
                         return FALSE;
                     }
 
@@ -739,7 +739,7 @@ file_copy:
                     if(preserve || move) {
                         if(getuid() == 0) {
                             if(lchown(dfile, stat_.st_uid, stat_.st_gid) < 0) {
-                                err_msg("file_copy: lchown err(%s)", dfile);
+                                merr_msg("file_copy: lchown err(%s)", dfile);
                                 return FALSE;
                             }
                         }
@@ -765,14 +765,14 @@ file_copy:
                     umask(umask_before);
 
                     if(result < 0) {
-                        err_msg("making character device(%s) is err. only root can do that", dfile);
+                        merr_msg("making character device(%s) is err. only root can do that", dfile);
                         return FALSE;
                     }
 
                     if(preserve || move) {
                         if(getuid() == 0) {
                             if(chown(dfile, stat_.st_uid, stat_.st_gid) < 0) {
-                                err_msg("file_copy: chown err(%s)", dfile);
+                                merr_msg("file_copy: chown err(%s)", dfile);
                                 return FALSE;
                             }
                         }
@@ -783,7 +783,7 @@ file_copy:
                         utb.modtime = stat_.st_mtime;
 
                         if(utime(dfile, &utb) < 0) {
-                            err_msg("file_copy: utime err(%s)", dfile);
+                            merr_msg("file_copy: utime err(%s)", dfile);
                             return FALSE;
                         }
                     }
@@ -830,14 +830,14 @@ file_copy:
                                  | S_IFBLK, makedev(major_, minor_));
                     umask(umask_before);
                     if(result < 0) {
-                        err_msg("file_copy: making block device(%s) is err.only root can do that", dfile);
+                        merr_msg("file_copy: making block device(%s) is err.only root can do that", dfile);
                         return FALSE;
                     }
 
                     if(preserve || move) {
                         if(getuid() == 0) {
                             if(chown(dfile, stat_.st_uid, stat_.st_gid) < 0) {
-                                err_msg("file_copy: chown() err (%s)", dfile);
+                                merr_msg("file_copy: chown() err (%s)", dfile);
                                 return FALSE;
                             }
                         }
@@ -848,7 +848,7 @@ file_copy:
                         utb.modtime = stat_.st_mtime;
 
                         if(utime(dfile, &utb) < 0) {
-                            err_msg("file_copy: utime err(%s)", dfile);
+                            merr_msg("file_copy: utime err(%s)", dfile);
                             return FALSE;
                         }
                     }
@@ -892,14 +892,14 @@ file_copy:
                                  | S_IFIFO, 0);
                     umask(umask_before);
                     if(result < 0) {
-                        err_msg("making fifo(%s) is err", dfile);
+                        merr_msg("making fifo(%s) is err", dfile);
                         return FALSE;
                     }
 
                     if(preserve || move) {
                         if(getuid() == 0) {
                             if(chown(dfile, stat_.st_uid, stat_.st_gid) < 0) {
-                                err_msg("file_copy: chown() err(%s)", dfile);
+                                merr_msg("file_copy: chown() err(%s)", dfile);
                                 return FALSE;
                             }
                         }
@@ -911,7 +911,7 @@ file_copy:
 
                         if(utime(dfile, &utb) < 0) 
                         {
-                            err_msg("file_copy: utime err(%s)", dfile);
+                            merr_msg("file_copy: utime err(%s)", dfile);
                             return FALSE;
                         }
                     }
@@ -954,14 +954,14 @@ file_copy:
                                  | S_IFSOCK, 0);
                     umask(umask_before);
                     if(result < 0) {
-                        err_msg("making socket(%s) is err", dfile);
+                        merr_msg("making socket(%s) is err", dfile);
                         return FALSE;
                     }
 
                     if(preserve || move) {
                         if(getuid() == 0) {
                             if(chown(dfile, stat_.st_uid, stat_.st_gid) < 0) {
-                                err_msg("file_copy: chown() err(%s)", dfile);
+                                merr_msg("file_copy: chown() err(%s)", dfile);
                                 return FALSE;
                             }
                         }
@@ -973,7 +973,7 @@ file_copy:
 
                         if(utime(dfile, &utb) < 0)
                         {
-                            err_msg("file_copy: utime() err(%s)", dfile);
+                            merr_msg("file_copy: utime() err(%s)", dfile);
                             return FALSE;
                         }
                     }
@@ -1010,7 +1010,7 @@ file_copy:
                 }
                 /// non suport file ///
                 else {
-                    err_msg("file_copy: sorry, non support file type(%s)", spath);
+                    merr_msg("file_copy: sorry, non support file type(%s)", spath);
                     return FALSE;
                 }
 
@@ -1117,15 +1117,15 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
                 switch(errno) {
                     case EACCES:
                     case EPERM:
-                        err_msg("file_remove: permission denied. (%s)", path);
+                        merr_msg("file_remove: permission denied. (%s)", path);
                         break;
 
                     case EROFS:
-                        err_msg("file_remove: file system is readonly. (%s)", path);
+                        merr_msg("file_remove: file system is readonly. (%s)", path);
                         break;
 
                     default:
-                        err_msg("file_remove: unlink err(%s)", path);
+                        merr_msg("file_remove: unlink err(%s)", path);
                         break;
                 }
                 return FALSE;
@@ -1139,7 +1139,7 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
             
             DIR* dir = opendir(path);
             if(dir == NULL) {
-                err_msg("file_remove: opendir err(%s)", path);
+                merr_msg("file_remove: opendir err(%s)", path);
                 return FALSE;
             }
             struct dirent* entry;
@@ -1159,7 +1159,7 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
                 }
             }
             if(closedir(dir) < 0) {
-                err_msg("file_remove: closedir() err");
+                merr_msg("file_remove: closedir() err");
                 return FALSE;
             }
 
@@ -1167,15 +1167,15 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
                 switch(errno) {
                     case EACCES:
                     case EPERM:
-                        err_msg("file_remove: permission denied.(%s)", path);
+                        merr_msg("file_remove: permission denied.(%s)", path);
                         break;
 
                     case EROFS:
-                        err_msg("file_remove: file system is readonly. (%s)", path);
+                        merr_msg("file_remove: file system is readonly. (%s)", path);
                         break;
 
                     default:
-                        err_msg("file_remove: rmdir err(%s)", path);
+                        merr_msg("file_remove: rmdir err(%s)", path);
                         break;
                 }
                 return FALSE;
