@@ -15,18 +15,18 @@ migemo* gMigemo;
 static regex_t* gReg;
 #endif
 
-static string_obj* gInputFileName;      // ͂ꂽ
+static string_obj* gInputFileName;      // 入力された文字列
 
 ///////////////////////////////////////////////////
-// Oɂ炷`
+// 外部にさらす定義
 ///////////////////////////////////////////////////
-BOOL gISearch = FALSE;                  // ݃CN^T[`ǂ
-BOOL gISearchPartMatch = FALSE;         // ݃CN^T[`p[g}b`ǂ
-BOOL gISearchExplore = FALSE;           // GLXv[[CN^T[`
-BOOL gNoPartMatchClear = FALSE;         // ISearchClargISearchPartMatchNA邩ǂ
-BOOL gISearchOption1 = TRUE;            // 擪CN^T[`s畔vCN^T[`IvV
+BOOL gISearch = FALSE;                  // 現在インクリメンタルサーチ中かどうか
+BOOL gISearchPartMatch = FALSE;         // 現在インクリメンタルサーチパートマッチ中かどうか
+BOOL gISearchExplore = FALSE;           // エキスプローラー風インクリメンタルサーチ
+BOOL gNoPartMatchClear = FALSE;         // ISearchClarでgISearchPartMatchをクリアするかどうか
+BOOL gISearchOption1 = TRUE;            // 先頭インクリメンタルサーチが失敗したら部分一致インクリメンタルサーチするオプション
 
-// ̕GNXv[[CN^T[`Ŏĝǂ
+// その文字がエクスプローラー風インクリメンタルサーチで使うものかどうか
 BOOL IsISearchExploreChar(int meta, int key)
 {
     return meta == 0 && ((key >= 'A' && key <= 'Z') 
@@ -54,10 +54,10 @@ void ISearchClear()
 }
 
 ///////////////////////////////////////////////////
-// `
+// 内部定義
 ///////////////////////////////////////////////////
 
-/// ͂ꂽ񂪃CN^T[`ǂ ///
+/// 入力された文字列がインクリメンタルサーチ向きかどうか ///
 static BOOL is_isearch_char(int key)
 {
     return key == 9 || (key >= ' ' && key <= '~')
@@ -68,142 +68,147 @@ static BOOL is_isearch_char(int key)
 //                && key != '?';
 }
 
-/// Ƀ}b`t@CɃJ[\ړ ///
+/// 後ろにマッチするファイル名にカーソルを移動 ///
 static BOOL match_back(int start)
 {
 #if !defined(HAVE_MIGEMO_H)
-    int i;
-    for(i=start; i>=0; i--) {
-        sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
-        char* fnamev = string_c_str(file->mNameView);
+    if(string_c_str(gInputFileName)[0] != 0) {
+        int i;
+        for(i=start; i>=0; i--) {
+            sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
+            char* fnamev = string_c_str(file->mNameView);
 
-        char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
-        if(!gISearchPartMatch &&  result == fnamev
-            || gISearchPartMatch && result != NULL)
-        {
-            filer_cursor_move(adir(), i);
-            return TRUE;
+            char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
+            if(!gISearchPartMatch &&  result == fnamev
+                || gISearchPartMatch && result != NULL)
+            {
+                filer_cursor_move(adir(), i);
+                return TRUE;
+            }
         }
     }
 
     return FALSE;
 
 #else
+    if(string_c_str(gInputFileName)[0] != 0) {
+        /// get reg ///
+        if(gReg == NULL) {
+            OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
+            if(p == NULL) {
+                return FALSE;
+            }
 
-    /// get reg ///
-    if(gReg == NULL) {
-        OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
-        if(p == NULL) {
-            return FALSE;
+            int r;
+            OnigErrorInfo err_info;
+
+            OnigUChar* p2 = MALLOC(sizeof(char)*strlen(p)*2);
+            char* p3 = p2;
+            char* p4 = p;
+            while(*p) {
+                if(*p == '+') {
+                    *p3++ = '\\';
+                    *p3++ = *p4++;
+                }
+                else {
+                    *p3++ = *p4++;
+                }
+            }
+            *p3 = 0;
+
+            if(gKanjiCode == kUtf8) {
+                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
+            }
+            else if(gKanjiCode == kEucjp) {
+                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
+            }
+            else if(gKanjiCode == kSjis) {
+                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
+            }
+
+            FREE(p2);
+
+            migemo_release(gMigemo, (unsigned char*) p);
+
+            if(r != ONIG_NORMAL) {
+                return FALSE;
+            }
         }
 
-        int r;
-        OnigErrorInfo err_info;
+        /// start ///
+        int i;
+        for(i=start; i>=0; i--) {
+            sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
+            char* fnamev = string_c_str(file->mNameView);
 
-        OnigUChar* p2 = MALLOC(sizeof(char)*strlen(p)*2);
-        char* p3 = p2;
-        char* p4 = p;
-        while(*p) {
-            if(*p == '+') {
-                *p3++ = '\\';
-                *p3++ = *p4++;
+            BOOL all_english = TRUE;
+            const int len = strlen(fnamev);
+            char* str = fnamev;
+            int j;
+            for(j=0; j<len; j++) {
+                if(!(str[j]>=' ' && str[j]<='~')) {
+                    all_english = FALSE;
+                }
+            }
+
+            if(all_english) {
+                char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
+                if(!gISearchPartMatch && result == fnamev
+                    || gISearchPartMatch && result != NULL)
+                {
+                    filer_cursor_move(adir(), i);
+                    //if(gReg) onig_free(gReg);
+                    //gReg = NULL;
+                    
+                    return TRUE;
+                }
+                
             }
             else {
-                *p3++ = *p4++;
-            }
-        }
-        *p3 = 0;
-
-        if(gKanjiCode == kUtf8) {
-            r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
-        }
-        else if(gKanjiCode == kEucjp) {
-            r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
-        }
-        else if(gKanjiCode == kSjis) {
-            r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
-        }
-
-        FREE(p2);
-
-        migemo_release(gMigemo, (unsigned char*) p);
-
-        if(r != ONIG_NORMAL) {
-            return FALSE;
-        }
-    }
-
-    /// start ///
-    int i;
-    for(i=start; i>=0; i--) {
-        sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
-        char* fnamev = string_c_str(file->mNameView);
-
-        BOOL all_english = TRUE;
-        const int len = strlen(fnamev);
-        char* str = fnamev;
-        int j;
-        for(j=0; j<len; j++) {
-            if(!(str[j]>=' ' && str[j]<='~')) {
-                all_english = FALSE;
-            }
-        }
-
-        if(all_english) {
-            char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
-            if(!gISearchPartMatch && result == fnamev
-                || gISearchPartMatch && result != NULL)
-            {
-                filer_cursor_move(adir(), i);
-                //if(gReg) onig_free(gReg);
-                //gReg = NULL;
+                OnigRegion* region = onig_region_new();
                 
-                return TRUE;
-            }
-            
-        }
-        else {
-            OnigRegion* region = onig_region_new();
-            
-            OnigUChar* str2 = (OnigUChar*)fnamev;
+                OnigUChar* str2 = (OnigUChar*)fnamev;
 
-            int r2 = onig_search(gReg, str2, str2 + strlen((char*)str2), str2, str2 + strlen((char*)str2), region, ONIG_OPTION_NONE);
+                int r2 = onig_search(gReg, str2, str2 + strlen((char*)str2), str2, str2 + strlen((char*)str2), region, ONIG_OPTION_NONE);
 
-            onig_region_free(region, 1);
+                onig_region_free(region, 1);
 
-            if(!gISearchPartMatch && r2 == 0
-                || gISearchPartMatch && r2 >= 0)
-            {
-                filer_cursor_move(adir(), i);
-                //if(gReg) onig_free(gReg);
-                //gReg = NULL;
-                return TRUE;
+                if(!gISearchPartMatch && r2 == 0
+                    || gISearchPartMatch && r2 >= 0)
+                {
+                    filer_cursor_move(adir(), i);
+                    //if(gReg) onig_free(gReg);
+                    //gReg = NULL;
+                    return TRUE;
+                }
             }
         }
+
+        //if(gReg) onig_free(gReg);
+        //gReg = NULL;
     }
 
-    //if(gReg) onig_free(gReg);
-    //gReg = NULL;
-
     return FALSE;
 #endif
 }
 
-/// OɃ}b`t@CɃJ[\ړ ///
+/// 前にマッチするファイル名にカーソルを移動 ///
 static BOOL match_next(int start)
 {
 #if !defined(HAVE_MIGEMO_H)
-    int i;
-    for(i=start; i<vector_size(filer_dir(adir())->mFiles); i++) {
-        sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
-        char* fnamev = string_c_str(file->mNameView);
+    if(string_c_str(gInputFileName)[0] != 0) {
+        int i;
+        for(i=start; i<vector_size(filer_dir(adir())->mFiles); i++) {
+            sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
+            char* fnamev = string_c_str(file->mNameView);
 
-        char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
-        if(!gISearchPartMatch &&  result == fnamev
-            || gISearchPartMatch && result != NULL)
-        {
-            filer_cursor_move(adir(), i);
-            return TRUE;
+            char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
+            if(!gISearchPartMatch &&  result == fnamev
+                || gISearchPartMatch && result != NULL)
+            {
+                filer_cursor_move(adir(), i);
+                return TRUE;
+            }
         }
     }
 
@@ -211,106 +216,108 @@ static BOOL match_next(int start)
 
 #else
 
-    /// get reg ///
-    if(gReg == NULL) {
-        OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
-        if(p == NULL) {
-            return FALSE;
-        }
+    if(string_c_str(gInputFileName)[0] != 0) {
+        /// get reg ///
+        if(gReg == NULL) {
+            OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
+            if(p == NULL) {
+                return FALSE;
+            }
 
-        OnigUChar* p2 = MALLOC(strlen(p)*2);
-        char* p3 = p2;
-        char* p4 = p;
-        while(*p4) {
-            if(*p4 == '+') {
-                *p3++ = '\\';
-                *p3++ = *p4++;
+            OnigUChar* p2 = MALLOC(strlen(p)*2);
+            char* p3 = p2;
+            char* p4 = p;
+            while(*p4) {
+                if(*p4 == '+') {
+                    *p3++ = '\\';
+                    *p3++ = *p4++;
+                }
+                else {
+                    *p3++ = *p4++;
+                }
+            }
+            *p3 = 0;
+
+            int r;
+            OnigErrorInfo err_info;
+
+            if(gKanjiCode == kUtf8) {
+                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
+            }
+            else if(gKanjiCode == kEucjp) {
+                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
             }
             else {
-                *p3++ = *p4++;
+                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
+            }
+            FREE(p2);
+            migemo_release(gMigemo, (unsigned char*) p);
+
+            if(r != ONIG_NORMAL) {
+                return FALSE;
             }
         }
-        *p3 = 0;
 
-        int r;
-        OnigErrorInfo err_info;
+        /// start ///
+        int i;
+        vector_obj* v = filer_dir(adir())->mFiles;
+        for(i=start; i<vector_size(v); i++) {
+            sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
+            char* fnamev = string_c_str(file->mNameView);
 
-        if(gKanjiCode == kUtf8) {
-            r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
-        }
-        else if(gKanjiCode == kEucjp) {
-            r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
-        }
-        else {
-            r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
-        }
-        FREE(p2);
-        migemo_release(gMigemo, (unsigned char*) p);
-
-        if(r != ONIG_NORMAL) {
-            return FALSE;
-        }
-    }
-
-    /// start ///
-    int i;
-    vector_obj* v = filer_dir(adir())->mFiles;
-    for(i=start; i<vector_size(v); i++) {
-        sFile* file = (sFile*)vector_item(filer_dir(adir())->mFiles, i);
-        char* fnamev = string_c_str(file->mNameView);
-
-        BOOL all_english = TRUE;
-        char* p = fnamev;
-        while(*p) {
-            if(!(*p>=' ' && *p<='~')) {
-                all_english = FALSE;
-                break;
+            BOOL all_english = TRUE;
+            char* p = fnamev;
+            while(*p) {
+                if(!(*p>=' ' && *p<='~')) {
+                    all_english = FALSE;
+                    break;
+                }
+                p++;
             }
-            p++;
-        }
 
-        if(all_english) {
-            char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
-            if(!gISearchPartMatch && result == fnamev
-                || gISearchPartMatch && result != NULL)
-            {
-                filer_cursor_move(adir(), i);
-                //if(gReg) onig_free(gReg);
-                //gReg = NULL;
+            if(all_english) {
+                char* result = mystrcasestr(fnamev, string_c_str(gInputFileName));
+                if(!gISearchPartMatch && result == fnamev
+                    || gISearchPartMatch && result != NULL)
+                {
+                    filer_cursor_move(adir(), i);
+                    //if(gReg) onig_free(gReg);
+                    //gReg = NULL;
+                    
+                    return TRUE;
+                }
                 
-                return TRUE;
             }
-            
-        }
-        else {
-            OnigRegion* region = onig_region_new();
-            
-            OnigUChar* str2 = (OnigUChar*)fnamev;
+            else {
+                OnigRegion* region = onig_region_new();
+                
+                OnigUChar* str2 = (OnigUChar*)fnamev;
 
-            int r2 = onig_search(gReg, str2, str2 + strlen((char*)str2), str2, str2 + strlen((char*)str2), region, ONIG_OPTION_NONE);
+                int r2 = onig_search(gReg, str2, str2 + strlen((char*)str2), str2, str2 + strlen((char*)str2), region, ONIG_OPTION_NONE);
 
-            onig_region_free(region, 1);
+                onig_region_free(region, 1);
 
-            if(!gISearchPartMatch && r2 == 0
-                || gISearchPartMatch && r2 >= 0)
-            {
-                filer_cursor_move(adir(), i);
-                //if(gReg) onig_free(gReg);
-                //gReg = NULL;
-                return TRUE;
+                if(!gISearchPartMatch && r2 == 0
+                    || gISearchPartMatch && r2 >= 0)
+                {
+                    filer_cursor_move(adir(), i);
+                    //if(gReg) onig_free(gReg);
+                    //gReg = NULL;
+                    return TRUE;
+                }
             }
         }
+
+        //if(gReg) onig_free(gReg);
+        //gReg = NULL;
     }
 
-    //if(gReg) onig_free(gReg);
-    //gReg = NULL;
-
     return FALSE;
 #endif
 }
 
 ///////////////////////////////////////////////////
-// CN^T[`
+// インクリメンタルサーチ初期化
 ///////////////////////////////////////////////////
 static void migemo_init()
 {
@@ -402,7 +409,7 @@ void isearch_init()
 }
 
 ///////////////////////////////////////////////////
-// CN^T[`
+// インクリメンタルサーチ解放
 ///////////////////////////////////////////////////
 void isearch_final()
 {
@@ -417,7 +424,7 @@ void isearch_final()
 }
 
 ///////////////////////////////////////////////////
-// CN^T[`L[
+// インクリメンタルサーチキー入力
 ///////////////////////////////////////////////////
 void isearch_input(int meta, int key)
 {
@@ -590,7 +597,7 @@ void isearch_explore_input(int meta, int key)
 }
 
 ///////////////////////////////////////////////////
-// CN^T[``
+// インクリメンタルサーチ描写
 ///////////////////////////////////////////////////
 void isearch_view()
 {
